@@ -1,16 +1,15 @@
-# -*- coding: utf-8 -*-
 """Tests for the `collector` module."""
+
 from unittest import mock
 
 import pytest
+from mkdocstrings import CollectionError
 
-from mkdocstrings.handlers.base import CollectionError
-from mkdocstrings.handlers.python import collector
+from mkdocstrings_handlers.python import get_handler
 
 
-def test_init():
-    """Test init for collector.PythonCollector."""
-    assert collector.PythonCollector()
+class _FakeMkDocsConfig:
+    config_file_path = "mkdocs.yml"
 
 
 @pytest.mark.parametrize(
@@ -21,16 +20,16 @@ def test_init():
         ({"error": "", "traceback": "hello"}, "\nhello"),
     ],
 )
-def test_collect_result_error(retval, exp_res):
+def test_collect_result_error(retval: dict, exp_res: str) -> None:
     """Test handling of errors when collecting an object.
 
     Args:
         retval: Return value to mock `json.loads` with.
         exp_res: Expected result.
     """
-    with mock.patch("mkdocstrings.handlers.python.collector.json.loads") as m_loads:
+    with mock.patch("mkdocstrings_handlers.python.handler.json.loads") as m_loads:  # noqa: SIM117
         with pytest.raises(CollectionError) as excinfo:  # noqa: PT012
             m_loads.return_value = retval
-            obj = collector.PythonCollector()
-            assert obj.collect("", {})
+            handler = get_handler({}, _FakeMkDocsConfig, theme="material")  # type: ignore[arg-type]
+            assert handler.collect("", {})
             assert str(excinfo.value) == exp_res
